
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.24.3.post1',
    'branch_nick': 'hotfix-1.24.3.post1',
    'revision_id': '2eb772488182d36aa567caf727fe8932d900383f',
    'revno': 10328
}
